@@ -4,17 +4,28 @@ import copy
 from ..lib.customer import find_usecase
 from django.apps import AppConfig
 
-
 class EnrichAppConfig(AppConfig):
 
     name="default"
-    namespace="default"
+    category = "default"
+    verbose_name = "default"
+    description = "default"
     filename = None
     enable = False
     multiple = False
     composition = False
     entry = "index"
     tags = ["store"]
+    _readme = ""
+
+    @property
+    def readme(cls):
+        if hasattr(cls, 'get_readme'):
+            return cls.get_readme()
+        elif cls._readme == "":
+            return cls.description
+        else:
+            return cls._readme
 
     def get_usecase(self):
 
@@ -39,3 +50,8 @@ class EnrichAppConfig(AppConfig):
 
     def is_enabled(self):
         return self.enable
+
+    def __str__(self):
+        return f"{self.name}: {self.verbose_name}"
+
+
