@@ -319,7 +319,7 @@ class MetricsBase(Compute):
                 datasets[name] = df
 
         missing = [s for s in required_sources if s not in found]
-        if len(missing) > 0: 
+        if len(missing) > 0:
             logger.error(
                 f"Missing {len(missing)} sources",
                 extra={
@@ -497,10 +497,11 @@ class MetricsBase(Compute):
         name = source["name"]
         dataset = source["dataset"]
         params = source.get("params", {})
+        filename = source.get('filename', 'data.csv')
 
         cache = args.get("cache", False)
-        cachename = f"{dataset}-{start_date}-{end_date}"
-        cachefile = f"cache/{self.name}-cache-" + cachename + ".csv"
+        cachename = f"{dataset}-{start_date}-{end_date}-{filename}"
+        cachefile = f"cache/{self.name}-cache-{cachename}"
 
         if cache:
             try:
