@@ -1385,6 +1385,12 @@ class Node(metaclass=NodeMeta):
             state.transform_overrides[name] = []
         state.transform_overrides[name].append(detail)
 
+    def pass_args(self, state, name, detail):
+        """
+        Alias for set_arg_overrides
+        """
+        return self.set_arg_overrides(state, name, detail)
+
     def frame_get_overrides(self, state_detail):
         """
         Obtain any extra instructions passed by previous
