@@ -18,7 +18,6 @@ from .resources import *
 
 logger = logging.getLogger("app")
 
-
 def greenbg(txt):
     return "{} \u2713 {} {}".format(bg("light_green"), txt, attr(0))
 
@@ -134,10 +133,14 @@ def read_siteconf(filename=None, app={}, context={}):
                 break
 
     if siteconf is None:
-        raise Exception(
-            "Could not find siteconf. Tried {} alternatives".format(len(tries))
+        logger.warning(
+            "Could not find siteconf. Using empty dict"
         )
 
+    siteconf = {
+        'credentials': {}
+    }
+
     return siteconf
 
 
